@@ -65,6 +65,7 @@ extern struct WINDOW windows[4];
 extern struct ATOM *atoms;
 extern struct ELEMENT *elements;
 extern struct ORBITAL *orbitals;
+extern struct BASISSET *basisset;
 extern Pixel stdcol[9], historyColor;
 extern float historyColor_rgb[4];
 extern int rgbMode, na, ne, nmodes, nhist, debug;
@@ -181,8 +182,8 @@ void colorEditor(Widget widget, caddr_t which, XmAnyCallbackStruct *data)
     case GNORM:      if (rgbMode)
 		 	   {
 			     r=historyColor_rgb[0];
-			     g=historyColor_rgb[0];
-			     b=historyColor_rgb[0];
+			     g=historyColor_rgb[1];
+			     b=historyColor_rgb[2];
 			     pixelSave=-1;
                      }
 			   else
@@ -557,7 +558,7 @@ void loadAtomColors()
       if (e[j] && e[j] == e[i]) e[i]=(struct ELEMENT *)0;
     }
   }
-  if (orbitals != NULL)
+  if (basisset != NULL || orbitals != NULL)
   {
     e=(struct ELEMENT **)expmem((void *)e, na+2, sizeof(struct ELEMENT *));
     for (k=0; k<ne; k++)
