@@ -10,9 +10,9 @@
 *
 * $Id: draw.c,v 1.1 1996/12/10 18:40:22 jrh Exp $
 * $Log: draw.c,v $
- * Revision 1.1  1996/12/10  18:40:22  jrh
- * Initial revision
- *
+* Revision 1.1  1996/12/10  18:40:22  jrh
+* Initial revision
+*
 *
 */
 #include<math.h>
@@ -71,7 +71,6 @@ extern char *bfname(int);
 extern void raytracerMaterial(struct ELEMENT *);
 extern void redraw(int);
 extern void *getmem(size_t, size_t);
-extern void *expmem(void *, size_t, size_t);
 extern void fremem(void **);
 
 extern struct ATOM *atoms;
@@ -227,7 +226,7 @@ void drawMolecule(Widget w, caddr_t client_data, GLwDrawingAreaCallbackStruct *d
     balls(1.3);
     stickModel(TRUE);
   }
-  if ((imo != -1 || ibasfu != 0 || iwavef != ALL_OFF) && !selectAtom)
+  if ((imo != -1 || ibasfu != -1 || iwavef != ALL_OFF) && !selectAtom)
   {
 /*  if (drawBegin == glBegin)
     { */
@@ -235,8 +234,10 @@ void drawMolecule(Widget w, caddr_t client_data, GLwDrawingAreaCallbackStruct *d
       {
         if (gridObjects[i].type == iwavef)
         {
-          if ((iwavef == MOLECULAR_ORBITAL && gridObjects[i].number == imo) ||
-              ((iwavef == BASIS_FUNCTION || iwavef == BASIS_IN_MO) && gridObjects[i].number == ibasfu) ||
+          if ((iwavef == MOLECULAR_ORBITAL && gridObjects[i].mo == imo) ||
+              (iwavef == BASIS_IN_MO && gridObjects[i].mo == imo &&
+                                        gridObjects[i].basisfunction == ibasfu) ||
+              (iwavef == BASIS_FUNCTION && gridObjects[i].basisfunction == ibasfu) ||
 		  iwavef == DENSITY)
           {
             found=i+1;
@@ -590,14 +591,14 @@ void drawTitle(Dimension w, Dimension h, int found)
   }
   else if (found)
   {
-    if (iwavef == BASIS_FUNCTION && ibasfu != 0)
+    if (iwavef == BASIS_FUNCTION && ibasfu != -1)
     {
       c=getStringResource(topShell, "basisfunctionTitle");
       sprintf(line1, c, ibasfu+1, atoms[bfatom].name, bfatom+1, bfname(ibasfu));
       c=getStringResource(topShell, "isosurfacePlusMinus");
       sprintf(line2, c, level, (-level));
     }
-    else if (iwavef == BASIS_IN_MO && ibasfu != 0)
+    else if (iwavef == BASIS_IN_MO && ibasfu != -1)
     {
       c=getStringResource(topShell, "basisfunctionInMOTitle");
       sprintf(line1, c, ibasfu+1, imo+1, atoms[bfatom].name, bfatom+1,
