@@ -10,9 +10,9 @@
 *
 * $Id: getrc.c,v 1.1 1996/12/10 18:41:02 jrh Exp $
 * $Log: getrc.c,v $
- * Revision 1.1  1996/12/10  18:41:02  jrh
- * Initial revision
- *
+* Revision 1.1  1996/12/10  18:41:02  jrh
+* Initial revision
+*
 *
 */
 #include<ctype.h>
@@ -33,9 +33,6 @@
 #include "viewmol.h"
 #include "dialog.h"
 #include "isotopes.h"
-#ifdef LINUX
-#define SYS_NMLN 65
-#endif
 
 void getPrimitive(char *, int *, int);
 int  getColor(GLfloat *p);
@@ -320,7 +317,7 @@ int getrc(void)
 	    messgb(topShell, 2, line, buttons1, 1);
 	    exit(-1);
 	  }
-	  if (++ne > mne)
+	  if (++ne >= mne)
 	  {
 	    mne+=10;
 	    elements=(struct ELEMENT *)expmem((void *)elements, mne, sizeof(struct ELEMENT));
