@@ -10,18 +10,20 @@
 *
 * $Id: hpgl.c,v 1.1 1996/12/10 18:41:12 jrh Exp $
 * $Log: hpgl.c,v $
- * Revision 1.1  1996/12/10  18:41:12  jrh
- * Initial revision
- *
+* Revision 1.1  1996/12/10  18:41:12  jrh
+* Initial revision
+*
 */
 #include<math.h>
 #include<stdio.h>
 #include<X11/Xlib.h>
 #include<GL/gl.h>
 #include "viewmol.h"
+#include "dialog.h"
 
 extern struct WINDOW windows[4];
 extern double tmat[4][4], prmat[4][4];
+
 static char pu[]="PU", pd[]="PD";
 static FILE *file=NULL;
 static double xnull, ynull, znull, fsx, fsy, pixel, stipple[8*sizeof(GLushort)];
@@ -81,7 +83,7 @@ FILE *hpglInit(char *filename, double left, double right, double bottom,
   lastpen=0;
   if (file == NULL)
   {
-    file=fopen(filename, "w");
+    if ((file=fopen(filename, "w")) == NULL) return(NULL);
     fprintf(file, "IN;\n");
     if (rotate)
       fprintf(file, "SC%f,%f,%f,%f;\n", bottom, top, left, right);
