@@ -45,6 +45,7 @@ extern int makeUnitCell(double, double, double, double, double, double, int);
 extern int getNumber(char *, int *);
 extern void cnorm(int);
 extern void modcmo(struct ORBITAL *, int, int, int, int, int, int);
+extern void assignBasisName(int, int);
 extern int checkFile(char **);
 
 extern struct ATOM *atoms;
@@ -666,7 +667,11 @@ int input(int argc, char **argv)
     else if (strstr(line, "$end"))
     {
 	pclose(file);
-      if (basisset != NULL && !gaussian) sortBasis();
+      if (basisset != NULL)
+	{
+	  if (!gaussian) sortBasis();
+	  assignBasisName(na, nbasfu);
+      }
       if (orbitals != NULL && ncoeff != 0)
       {
         if (basisset != NULL)
