@@ -10,9 +10,9 @@
 *
 * $Id: printform.c,v 1.1 1996/12/10 18:43:19 jrh Exp $
 * $Log: printform.c,v $
- * Revision 1.1  1996/12/10  18:43:19  jrh
- * Initial revision
- *
+* Revision 1.1  1996/12/10  18:43:19  jrh
+* Initial revision
+*
 *
 */
 #include<stdlib.h>
@@ -50,7 +50,7 @@ extern void GetInsWeight(Widget, caddr_t, XmAnyCallbackStruct *);
 extern Widget makeMenu(Widget, int, char *, struct MenuItem *);
 extern void MapBox(Widget, caddr_t, XmAnyCallbackStruct *);
 extern Widget CreateToggleBox(Widget, struct PushButtonRow *, int, int,
-                              int, int);
+                              int, int, int);
 extern char *selectFile(char *, char *);
 extern char *getStringResource(Widget, char *);
 extern char *saveVectorFile(int, char *, int);
@@ -126,7 +126,8 @@ void printDialog(Widget widget, caddr_t which, XmAnyCallbackStruct *data)
     XtSetArg(args[2], XmNmwmDecorations, MWM_DECOR_RESIZEH | MWM_DECOR_TITLE);
   else
     XtSetArg(args[2], (char *)NULL, 0);
-  dialog=XmCreateDialogShell(windows[window].widget, "printForm_popup", args, XtNumber(args));
+  dialog=XmCreateDialogShell(XtParent(windows[window].widget), "printForm_popup",
+				     args, XtNumber(args));
   board=XtVaCreateWidget("printForm", xmFormWidgetClass, dialog,
                          XmNautoUnmanage, False,
                          XmNdefaultPosition, False,
@@ -145,7 +146,7 @@ void printDialog(Widget widget, caddr_t which, XmAnyCallbackStruct *data)
                          XmNrightAttachment, XmATTACH_FORM,
                          NULL);
   radiobox1=CreateToggleBox(form1, radiobox1_buttons, XtNumber(radiobox1_buttons),
-                            XmVERTICAL, True, format-2);
+                            XmVERTICAL, 1, True, format-2);
   if (window != VIEWER || (windows[VIEWER].mode == WIREMODEL && iwavef == ALL_OFF))
      XtVaSetValues(radiobox1_buttons[RAYTRACER-2].widget, XmNsensitive, False, NULL);
   if ((animate == ANIMATE && mode != (-1) && window == VIEWER) ||
@@ -179,7 +180,7 @@ void printDialog(Widget widget, caddr_t which, XmAnyCallbackStruct *data)
 				 XmNrightAttachment, XmATTACH_FORM,
                          NULL);
   radiobox2=CreateToggleBox(form2, radiobox2_buttons, XtNumber(radiobox2_buttons),
-                            XmVERTICAL, True, landscape ? 0 : 1);
+                            XmVERTICAL, 1, True, landscape ? 0 : 1);
   XtVaSetValues(radiobox2,XmNrightAttachment, XmATTACH_FORM,
                           XmNtopAttachment, XmATTACH_FORM,
                           NULL);
@@ -512,8 +513,11 @@ void printDialogExit(Widget button, caddr_t which, XmPushButtonCallbackStruct *d
 				 word=saveVectorFile(window, file, format);
                        break;
     }
-    sprintf(str, word, file);
-    messgb(topShell, 0, str, buttons, 1);
+    if (word)
+    {
+      sprintf(str, word, file);
+      messgb(topShell, 0, str, buttons, 1);
+    }
     XtFree(file);
   }
   XtDestroyWidget(dialog);
