@@ -10,9 +10,9 @@
 *
 * $Id: readgauss.c,v 1.1 1996/12/10 18:43:35 jrh Exp $
 * $Log: readgauss.c,v $
- * Revision 1.1  1996/12/10  18:43:35  jrh
- * Initial revision
- *
+* Revision 1.1  1996/12/10  18:43:35  jrh
+* Initial revision
+*
 */
 
 #include<ctype.h>
@@ -59,14 +59,14 @@ extern void fremem(void **);
 void main(int argc, char **argv)
 {
   FILE *file;
-  double etotal;
+/*double etotal;*/
   char emark[2][7] = {"0@  ~0", "0@  ~0"}, line[MAXLENLINE], *word;
   char *symbol;
   int freq=FALSE, gfprn=FALSE, opt=FALSE;
   int nemark=0, nout, na, ncent, nuc, mna=50;
-  int etex;
+/*int etex; */
   register double x, y, z;
-  register int i, mak;
+  register int i; /* mak;*/
 
   if ((file=fopen(argv[1], "r")) == NULL) eof("noFile", argv[1], 1);
 
@@ -111,11 +111,20 @@ void main(int argc, char **argv)
       strcpy(emark[0], EMP4);
       nemark=1;
     }
-    printf("$pople ");
-    if (!strstr(line, "5d")) printf("6d ");
-    if (!strstr(line, "7f")) printf("10f ");
-    printf("\n");
-  
+    if (!strncmp(line, " #", 2))
+    {
+      printf("$pople ");
+      if (!strstr(line, "5d"))
+  	  printf("6d ");
+      else
+  	  printf("5d ");
+      if (!strstr(line, "7f"))
+  	  printf("10f ");
+      else
+  	  printf("7f");
+      printf("\n");
+    }
+
 /* AdM added IF block for DFT overruling all previous stuff */
 
     if (strstr(line, "lyp") || strstr(line, "pl") || strstr(line, "andh") ||
@@ -153,9 +162,9 @@ void main(int argc, char **argv)
     makeLower(line);
   } while (!strstr(line, FRAME));
   if (strstr(line, "C*V") || strstr(line, "D*H"))
-     nout=5;
+    nout=5;
   else
-     nout=6;
+    nout=6;
   strtok(line, " \t");
   strtok(NULL, " \t");
   word=strtok(NULL, "[");
@@ -192,7 +201,7 @@ void main(int argc, char **argv)
 	symbol[3*na+1]=pse[nuc][1];
 	symbol[3*na+2]='\0';
 	printf("%22.14f%22.14f%22.14f  %s\n", x, y, z, &symbol[3*na]);
-	if (++na > mna)
+	if (++na >= mna)
 	{
 	  mna+=50;
 	  symbol=(char *)expmem((void *)symbol, mna, 3*sizeof(char));
@@ -215,13 +224,13 @@ void main(int argc, char **argv)
 
 /* Load total energy */
 
-  do
+/*do
   {
     if (fgets(line, MAXLENLINE, file) == NULL) eof("noEnergy", argv[1], 0);
     makeLower(line);
   } while ((mak=msub(line, nemark, &emark[0][0])) == 0);
   etotal=reade(line, emark[mak], &etex);
-  if (!etex) exit(-1);
+  if (!etex) exit(-1); */
 
 /* Load orbital energies and symmetries */
 
@@ -307,7 +316,7 @@ void readBasis(FILE *file, int na)
       sscanf(word, "%12le%12le%12le%12le%12le", &ex[i], &scoeff[i],
 		 &pcoeff[i], &dcoeff[i], &fcoeff[i]);
       ex[i++]*=scalefactor;
-	if (i > maxpri)
+	if (i >= maxpri)
 	{
 	  maxpri+=20;
         ex=(double *)expmem((void *)ex, maxpri, sizeof(double));
@@ -460,7 +469,7 @@ void readMOs(FILE *file)
       for (i=0; i<ie; i++)
       {
 	  cmo[k]=atof(strtok(NULL, " \t"));
-        if (++k > mnc)
+        if (++k >= mnc)
 	  {
 	    mnc+=200;
 	    cmo=(double *)expmem((void *)cmo, mnc, sizeof(double));
@@ -573,11 +582,16 @@ void readFrq(FILE *file, int na, int nout)
   printf("$vibrational normal modes\n");
   for (i=0; i<ncart+nout; i++)
   {
-    printf("%2d  1", i+1);
     for (j=0; j<ncart; j++)
     {
+	if (j % 5 == 0)
+	{
+	  if (j == 0)
+	    printf("%2d %2d ", i+1, j/5+1);
+        else
+	    printf("\n%2d %2d ", i+1, j/5+1);
+      }
 	printf("%15.10f", nmo[i*ncart+j]);
-	if ((j+1) % 5 == 0) printf("\n%2d %2d ", i+1, (j+1)/5+1);
     }
     printf("\n");
   }
@@ -598,11 +612,11 @@ void readOpg(FILE *file, int na, int nemark, char *emark)
   register int i, nuc;
 
   x=(double *)getmem(na, 6*sizeof(double));
-  y=x+na*sizeof(double);
-  z=y+na*sizeof(double);
-  gx=z+na*sizeof(double);
-  gy=gx+na*sizeof(double);
-  gz=gy+na*sizeof(double);
+  y=x+na;
+  z=y+na;
+  gx=z+na;
+  gy=gx+na;
+  gz=gy+na;
   symbol=(char *)getmem(na, 3*sizeof(char));
 
   rewind(file);
@@ -687,7 +701,7 @@ void readOpg(FILE *file, int na, int nemark, char *emark)
     strtok(NULL, " \t");
     strtok(NULL, " \t");
     gnorm=atof(strtok(NULL, " \t"));
-    if (cycle++) printf("$grad\n");
+    if (!cycle++) printf("$grad\n");
     printf("  cycle = %3d    SCF energy = %17.10f   |dE/xyz| = %9.6f\n", cycle, energy, gnorm);
     for (i=0; i<na; i++)
       printf("%22.14f%22.14f%22.14f  %s\n", x[i], y[i], z[i], &symbol[3*i]);
