@@ -10,9 +10,9 @@
 *
 * $Id: specform.c,v 1.1 1996/12/10 18:44:01 jrh Exp $
 * $Log: specform.c,v $
- * Revision 1.1  1996/12/10  18:44:01  jrh
- * Initial revision
- *
+* Revision 1.1  1996/12/10  18:44:01  jrh
+* Initial revision
+*
 *
 */
 #include<stdlib.h>
@@ -52,7 +52,7 @@ void GetInsWeight(Widget, caddr_t, XmToggleButtonCallbackStruct *);
 
 extern void MapBox(Widget, caddr_t, XmAnyCallbackStruct *);
 extern Widget CreateToggleBox(Widget, struct PushButtonRow *, int, int,
-			            int, int);
+			            int, int, int);
 extern char *getStringResource(Widget, char *);
 extern void CreatePushButtonRow(Widget, struct PushButtonRow *, int);
 extern void setWindowTitle(Widget, char *);
@@ -122,7 +122,8 @@ void spectrumDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
     XtSetArg(args[2], XmNmwmDecorations, MWM_DECOR_RESIZEH | MWM_DECOR_TITLE);
   else
     XtSetArg(args[2], (char *)NULL, 0);
-  dialog=XmCreateDialogShell(windows[SPECTRUM].widget, "spectrumForm_popup", args, XtNumber(args));
+  dialog=XmCreateDialogShell(XtParent(windows[SPECTRUM].widget),
+				     "spectrumForm_popup", args, XtNumber(args));
   board=XtVaCreateWidget("spectrumForm", xmBulletinBoardWidgetClass, dialog,
                          XmNautoUnmanage, False,
                          XmNdefaultPosition, False,
@@ -153,7 +154,7 @@ void spectrumDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
   form3=XtVaCreateWidget("controlarea3", xmFormWidgetClass, form1, NULL);
 
   radiobox1=CreateToggleBox(form2, radiobox1_buttons, XtNumber(radiobox1_buttons),
-                            XmVERTICAL, True, windows[SPECTRUM].mode-1);
+                            XmVERTICAL, 1, True, windows[SPECTRUM].mode-1);
   XtVaSetValues(radiobox1, XmNleftAttachment, XmATTACH_FORM,
                            XmNtopAttachment, XmATTACH_FORM,
                            XmNrightAttachment, XmATTACH_FORM,
@@ -167,7 +168,7 @@ void spectrumDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
                                NULL);
 
   radiobox2=CreateToggleBox(form2, radiobox2_buttons, XtNumber(radiobox2_buttons),
-                            XmVERTICAL, True, animate-1);
+                            XmVERTICAL, 1, True, animate-1);
   XtVaSetValues(radiobox2, XmNleftAttachment, XmATTACH_FORM,
                            XmNtopAttachment, XmATTACH_WIDGET,
                            XmNtopWidget, sep2,
@@ -182,7 +183,7 @@ void spectrumDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
                                NULL);
 
   radiobox3=CreateToggleBox(form2, radiobox3_buttons, XtNumber(radiobox3_buttons),
-                            XmVERTICAL, True, lines ? 0 : 1);
+                            XmVERTICAL, 1, True, lines ? 0 : 1);
   XtVaSetValues(radiobox3, XmNtopAttachment, XmATTACH_WIDGET,
                            XmNtopWidget, sep3,
                            XmNleftAttachment, XmATTACH_FORM,
