@@ -10,9 +10,9 @@
 *
 * $Id: waveform.c,v 1.1 1996/12/10 18:44:23 jrh Exp $
 * $Log: waveform.c,v $
- * Revision 1.1  1996/12/10  18:44:23  jrh
- * Initial revision
- *
+* Revision 1.1  1996/12/10  18:44:23  jrh
+* Initial revision
+*
 *
 */
 #include<math.h>
@@ -45,7 +45,7 @@ extern void MapBox(Widget, caddr_t, caddr_t);
 extern void GetUnit(Widget, struct TOGGLE *, XmPushButtonCallbackStruct *);
 extern void GetSlider(Widget, struct SLIDER *, XmScrollBarCallbackStruct *);
 extern Widget CreateToggleBox(Widget, struct PushButtonRow *, int, int,
-                              int, int);
+                              int, int, int);
 extern char *getStringResource(Widget, char *);
 extern void CreatePushButtonRow(Widget, struct PushButtonRow *, int);
 extern int checkFile(char **);
@@ -113,7 +113,8 @@ void wavefunctionDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
     XtSetArg(args[2], XmNmwmDecorations, MWM_DECOR_RESIZEH | MWM_DECOR_TITLE);
   else
     XtSetArg(args[2], (char *)NULL, 0);
-  dialog=XmCreateDialogShell(windows[VIEWER].widget, "wavefunctionForm_popup", args, XtNumber(args));
+  dialog=XmCreateDialogShell(XtParent(windows[VIEWER].widget),
+				     "wavefunctionForm_popup", args, XtNumber(args));
   board=XtVaCreateWidget("wavefunctionForm", xmBulletinBoardWidgetClass, dialog,
                         XmNautoUnmanage, False,
                         XmNdefaultPosition, False,
@@ -136,7 +137,7 @@ void wavefunctionDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
   toggle1[4].value=DENSITY;
 
   checkbox1=CreateToggleBox(form1, checkbox1_buttons, XtNumber(checkbox1_buttons),
-                            XmVERTICAL, True, iwavef-1);
+                            XmVERTICAL, 1, True, iwavef-1);
 
   if (orbitals != NULL)
   {
@@ -217,7 +218,7 @@ void wavefunctionDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
   toggle2[1].value=IP_LINEAR;
   toggle2[2].value=IP_LOG;
   checkbox2=CreateToggleBox(form1, checkbox2_buttons, XtNumber(checkbox2_buttons),
-                           XmVERTICAL, True, interp-1);
+                           XmVERTICAL, 1, True, interp-1);
 
   XtVaSetValues(checkbox2, XmNleftAttachment, XmATTACH_FORM,
                            XmNrightAttachment, XmATTACH_FORM,
@@ -276,7 +277,7 @@ void wavefunctionDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
 void wavefunctionDialogExit(Widget widget, caddr_t which, XmPushButtonCallbackStruct *data)
 {
   int found=FALSE;
-  register int i=0, j;
+  register int j;
 
   XtDestroyWidget(dialog);
   if (!(int)which)
@@ -294,14 +295,13 @@ void wavefunctionDialogExit(Widget widget, caddr_t which, XmPushButtonCallbackSt
                               break;
       case BASIS_FUNCTION:
       case BASIS_IN_MO:       selectAtom=TRUE;
-					i=ibasfu;
                               break;
-      case MOLECULAR_ORBITAL: i=imo;
+      case MOLECULAR_ORBITAL:
       case DENSITY:           selectAtom=FALSE;
 					for (j=0; j<ngridobjects; j++)
 					{
 					  if (gridObjects[j].type       == iwavef &&
-						gridObjects[j].number     == i      &&
+						gridObjects[j].mo         == imo    &&
 						gridObjects[j].resolution == gridres)
 					  {
 					    found=TRUE;
